==> am_mod_blg_0_3.zip: am_mod_blg_0_3/components/blg/language/1/barnraiser_01/blog_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/blg_common.inc.php');


// HEADER
$lang['hdr_blog'] = 								"blog";
$lang['hdr_permissions'] = 							"permissions";
$lang['hdr_starting_a_blog'] = 						"creating your blog";


// SUBMIT BUTTONS
$lang['sub_update'] =                            	"save";


// ERROR MESSAGES
$lang['error']['title_empty'] = 					"You have not given a title to your blog.";
$lang['error']['synopsis_empty'] = 					"You have not given a synopsis to your blog.";


// BODY TEXT
$lang['txt_image'] = 								"images";
$lang['txt_none'] = 								"none";
$lang['txt_title'] = 								"title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_publish'] = 								"publish";
$lang['txt_language'] = 							"language";
$lang['txt_blog_create_intro'] =					"Once you create your blog you will be taken to the blog home page where you can create your first blog entry";
$lang['txt_status'] = 								"status";
$lang['txt_participation'] = 						"participation";
$lang['txt_my_identity'] =							"my identity";

?>

==> am_mod_blg_0_4.zip: am_mod_blg_0_4/components/blg/language/1/barnraiser_01/blog_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/blg_common.inc.php');


// HEADER
$lang['hdr_blog'] = 								"blog";
$lang['hdr_starting_a_blog'] = 						"creating your blog";


// SUBMIT BUTTONS
$lang['sub_update'] =                            	"save";


// ERROR MESSAGES
$lang['error']['title_empty'] = 					"You have not given a title to your blog.";
$lang['error']['synopsis_empty'] = 					"You have not given a synopsis to your blog.";


// BODY TEXT
$lang['txt_image'] = 								"images";
$lang['txt_none'] = 								"none";
$lang['txt_title'] = 								"title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_publish'] = 								"publish";
$lang['txt_language'] = 							"language";
$lang['txt_blog_create_intro'] =					"Once you create your blog you will be taken to the blog home page where you can create your first blog entry";
$lang['txt_status'] = 								"status";
$lang['txt_participation'] = 						"participation";
$lang['txt_my_identity'] =							"my identity";

$lang['txt_file_to_upload'] = 						"file";
$lang['txt_file_to_upload_name'] = 					"filename";
$lang['txt_title_intro'] = 							"describe your blog";
$lang['txt_title_image'] = 							"add a thumbnail image to your blog";
$lang['txt_title_save'] = 							"check and save your blog";
$lang['txt_title_permissions'] = 					"set permissions for the blog";

?>
